# Generated by roxygen2: do not edit by hand

export("resource<-")
export(BiocFileList)
export(FileForFormat)
export(decompress)
export(export)
export(fileFormat)
export(import)
export(resource)
exportClasses(BiocFile)
exportClasses(BiocFileList)
exportClasses(CompressedFile)
exportMethods("resource<-")
exportMethods(as.character)
exportMethods(decompress)
exportMethods(export)
exportMethods(fileFormat)
exportMethods(import)
exportMethods(path)
exportMethods(resource)
exportMethods(show)
importFrom(BiocBaseUtils,isScalarCharacter)
importFrom(BiocGenerics,path)
importFrom(S4Vectors,SimpleList)
importFrom(S4Vectors,isSingleString)
importFrom(methods,findMethods)
importFrom(methods,getClass)
importFrom(methods,getClassDef)
importFrom(methods,is)
importFrom(methods,new)
importFrom(methods,packageSlot)
importFrom(methods,show)
importFrom(tools,file_ext)
importFrom(tools,file_path_as_absolute)
importFrom(tools,file_path_sans_ext)
