# BiocIO

The BiocIO package contains high-level abstract classes and generics used by
developers to build IO funcionality within the Bioconductor suite of
packages.

## Abstract Classes
- BiocFile
- CompressedFile

## Generics
- export
- import
